@@ -92,6 +92,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Rafael \"EagleScreen\" Belmonte</b></dt><dd>Spanish translation</dd>"
                               "<dt><b>Sergiu Bivol</b></dt><dd>Romanian translation</dd>"
                               "<dt><b>Bruno Brigras</b></dt><dd>Crash fixes</dd>"
+                              "<dt><b>Florent Castelli</b></dt><dd>Sanitize topic handling</dd>"
                               "<dt><b>Theo \"tampakrap\" Chatzimichos</b></dt><dd>Greek translation</dd>"
                               "<dt><b>Yuri Chornoivan</b></dt><dd>Ukrainian translation</dd>"
                               "<dt><b>Tomáš \"scarabeus\" Chvátal</b></dt><dd>Czech translation</dd>"
@@ -101,11 +102,13 @@ QString AboutDlg::contributors() const
                               "<dt><b>Matthias \"pennywise\" Coy</b></dt><dd>German translation</dd>"
                               "<dt><b>\"derpella\"</b></dt><dd>Polish translation</dd>"
                               "<dt><b>\"Dorian\"</b></dt><dd>French translation</dd>"
+                              "<dt><b>Luke Faraone</b></dt><dd>Doc fixes</dd>"
                               "<dt><b>Chris \"stitch\" Fuenty</b></dt><dd>SASL support</dd>"
                               "<dt><b>Kevin \"KRF\" Funk</b></dt><dd>German translation</dd>"
                               "<dt><b>Fabiano \"elbryan\" Francesconi</b></dt><dd>Italian translation</dd>"
                               "<dt><b>Leo Franchi</b></dt><dd>OSX improvements</dd>"
                               "<dt><b>Sebastien Fricker</b></dt><dd>Audio backend improvements</dd>"
+                              "<dt><b>Alf Gaida</b></dt><dd>Language improvements</dd>"
                               "<dt><b>Aurélien \"agateau\" Gâteau</b></dt><dd>Message Indicator support</dd>"
                               "<dt><b>Marco \"kaffeedoktor\" Genise</b></dt><dd>Ideas, hacking, motivation</dd>"
                               "<dt><b>Felix \"debfx\" Geyer</b></dt><dd>Certificate handling improvements</dd>"
@@ -130,8 +133,10 @@ QString AboutDlg::contributors() const
                               "<dt><b>\"Larso\"</b></dt><dd>Finnish translation</dd>"
                               "<dt><b>Patrick \"bonsaikitten\" Lauer</b></dt><dd>Gentoo packaging</dd>"
                               "<dt><b>Chris \"Fish-Face\" Le Sueur</b></dt><dd>Various fixes and improvements</dd>"
+                              "<dt><b>Jerome \"Adys\" Leclanche</b></dt><dd>Context menu fixes</dd>"
                               "<dt><b>Hendrik \"nevcairiel\" Leppkes</b></dt><dd>Various features</dd>"
                               "<dt><b>Jason Lynch</b></dt><dd>Bugfixes</dd>"
+                              "<dt><b>Michael \"mamarley\" Marley</b></dt><dd>Various fixes and improvements</dd>"
                               "<dt><b>Martin \"m4yer\" Mayer</b></dt><dd>German translation</dd>"
                               "<dt><b>Daniel \"hydrogen\" Meltzer</b></dt><dd>Various fixes and improvements</dd>"
                               "<dt><b>Daniel E. Moctezuma</b></dt><dd>Japanese translation</dd>"
@@ -139,6 +144,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Thomas Müller</b></dt><dd>Fixes, Debian packaging</dd>"
                               "<dt><b>Gábor \"ELITE_x\" Németh</b></dt><dd>Hungarian translation</dd>"
                               "<dt><b>Per Nielsen</b></dt><dd>Danish translation</dd>"
+                              "<dt><b>J-P Nurmi</b></dt><dd>Fixes</dd>"
                               "<dt><b>Marco \"Quizzlo\" Paolone</b></dt><dd>Italian translation</dd>"
                               "<dt><b>Bas \"Tucos\" Pape</b></dt><dd>Many fixes and improvements, bug and patch triaging, tireless community support</dd>"
                               "<dt><b>Bruno Patri</b></dt><dd>French translation</dd>"
@@ -152,7 +158,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Nuno \"pinheiro\" Pinheiro</b></dt><dd>Tons of Oxygen icons including our application icon</dd>"
                               "<dt><b>David Planella</b></dt><dd>Translation system fixes</dd>"
                               "<dt><b>Jure \"JLP\" Repinc</b></dt><dd>Slovenian translation</dd>"
-                              "<dt><b>Patrick \"TheOneRing\" von Reth</b></dt><dd>MinGW support, Windows packager</dd>"
+                              "<dt><b>Patrick \"TheOneRing\" von Reth</b></dt><dd>MinGW support, SNORE backend, Windows packager</dd>"
                               "<dt><b>Dirk \"MarcLandis\" Rettschlag</b></dt><dd>Various fixes and new features</dd>"
                               "<dt><b>Miguel Revilla</b></dt><dd>Spanish translation</dd>"
                               "<dt><b>Jaak Ristioja</b></dt><dd>Fixes</dd>"
@@ -171,6 +177,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Alexander Stein</b></dt><dd>Tray icon fix</dd>"
                               "<dt><b>Daniel \"son\" Steinmetz</b></dt><dd>Early beta tester and bughunter (on Vista&trade;!)</dd>"
                               "<dt><b>Jesper Thomschütz</b></dt><dd>Various fixes</dd>"
+                              "<dt><b>Arthur \"roentgen\" Titeica</b></dt><dd>Romanian translation</dd>"
                               "<dt><b>\"ToBeFree\"</b></dt><dd>German translation</dd>"
                               "<dt><b>Edward \"Aides\" Toroshchin</b></dt><dd>Russian translation</dd>"
                               "<dt><b>Adam \"adamt\" Tulinius</b></dt><dd>Early beta tester and bughunter, Danish translation</dd>"
