@@ -38,7 +38,7 @@ ChatViewSettingsPage::ChatViewSettingsPage(QWidget *parent)
     if (!(Client::coreFeatures() & Quassel::SynchronizedMarkerLine)) {
         ui.autoMarkerLine->setEnabled(false);
         ui.autoMarkerLine->setChecked(true);
-        ui.autoMarkerLine->setToolTip(tr("You need at 0.6 quasselcore to use this feature"));
+        ui.autoMarkerLine->setToolTip(tr("You need at least version 0.6 of quasselcore to use this feature"));
     }
 
     initAutoWidgets();
